# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/email_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/community/email_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import email_type_pb2 as eolymp_dot_community_dot_email__type__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/community/email_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/community/email_type.proto\x1a\x1d\x65olymp/community/member.proto\x1a\x18\x65olymp/ecm/content.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaf\x02\n\x0eSendEmailInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x14 \x01(\x08\x12\x0e\n\x06\x62\x63\x63_me\x18\x15 \x01(\x08\x12)\n\x04type\x18\n \x01(\x0e\x32\x1b.eolymp.community.EmailType\x12\x0e\n\x06locale\x18\x0b \x01(\t\x12\x0f\n\x07subject\x18\x0c \x01(\t\x12$\n\x07\x63ontent\x18\r \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x44\n\nparameters\x18\x0e \x03(\x0b\x32\x30.eolymp.community.SendEmailInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x0fSendEmailOutput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65scribeEmailUsageInput\"H\n\x18\x44\x65scribeEmailUsageOutput\x12\x14\n\x0c\x64\x61ily_emails\x18\x02 \x01(\r\x12\x16\n\x0emonthly_emails\x18\x03 \x01(\r2\xe4\x02\n\x0c\x45mailService\x12\xa2\x01\n\tSendEmail\x12 .eolymp.community.SendEmailInput\x1a!.eolymp.community.SendEmailOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/members/{member_id}/notify\x12\xae\x01\n\x12\x44\x65scribeEmailUsage\x12).eolymp.community.DescribeEmailUsageInput\x1a*.eolymp.community.DescribeEmailUsageOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x0f\x12\r/usage/emailsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.email_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EMAILSERVICE'].methods_by_name['SendEmail']._loaded_options = None
  _globals['_EMAILSERVICE'].methods_by_name['SendEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\035\"\033/members/{member_id}/notify'
  _globals['_EMAILSERVICE'].methods_by_name['DescribeEmailUsage']._loaded_options = None
  _globals['_EMAILSERVICE'].methods_by_name['DescribeEmailUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\017\022\r/usage/emails'
  _globals['_SENDEMAILINPUT']._serialized_start=352
  _globals['_SENDEMAILINPUT']._serialized_end=655
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._serialized_start=606
  _globals['_SENDEMAILINPUT_PARAMETERSENTRY']._serialized_end=655
  _globals['_SENDEMAILOUTPUT']._serialized_start=657
  _globals['_SENDEMAILOUTPUT']._serialized_end=694
  _globals['_DESCRIBEEMAILUSAGEINPUT']._serialized_start=696
  _globals['_DESCRIBEEMAILUSAGEINPUT']._serialized_end=721
  _globals['_DESCRIBEEMAILUSAGEOUTPUT']._serialized_start=723
  _globals['_DESCRIBEEMAILUSAGEOUTPUT']._serialized_end=795
  _globals['_EMAILSERVICE']._serialized_start=798
  _globals['_EMAILSERVICE']._serialized_end=1154
# @@protoc_insertion_point(module_scope)
