# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/evaluation_report.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/executor/evaluation_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/executor/evaluation_report.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/stats.proto\"\xc1\n\n\x10\x45valuationReport\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12\x41\n\x08metadata\x18\x05 \x03(\x0b\x32/.eolymp.executor.EvaluationReport.MetadataEntry\x12\r\n\x05\x61gent\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x32 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x34\n\x04type\x18\n \x01(\x0e\x32&.eolymp.executor.EvaluationReport.Type\x12\x38\n\x06status\x18\x0b \x01(\x0e\x32(.eolymp.executor.EvaluationReport.Status\x12\x15\n\rerror_message\x18\x14 \x01(\t\x12\x33\n\x04runs\x18( \x03(\x0b\x32%.eolymp.executor.EvaluationReport.Run\x1a\xc4\x05\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.eolymp.executor.EvaluationReport.Run.Status\x12\r\n\x05score\x18P \x01(\x02\x12\x0c\n\x04\x63ost\x18Q \x01(\x02\x12\x12\n\ntime_usage\x18\x33 \x01(\r\x12\x12\n\ntime_limit\x18= \x01(\r\x12\x11\n\tcpu_usage\x18\x34 \x01(\r\x12\x11\n\tcpu_limit\x18> \x01(\r\x12\x14\n\x0cmemory_usage\x18\x35 \x01(\x04\x12\x14\n\x0cmemory_limit\x18? \x01(\x04\x12\x18\n\x10time_coefficient\x18\x0e \x01(\x02\x12\x11\n\tinput_url\x18\n \x01(\t\x12\x12\n\noutput_url\x18\x0b \x01(\t\x12\x12\n\nanswer_url\x18\x0c \x01(\t\x12+\n\x0b\x64\x65\x62ug_stats\x18Z \x01(\x0b\x32\x16.eolymp.executor.Stats\x12-\n\rchecker_stats\x18# \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x30\n\x10interactor_stats\x18- \x01(\x0b\x32\x16.eolymp.executor.Stats\"\xf1\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x11\n\rRUNTIME_ERROR\x10\x06\x12\x0c\n\x08\x45XECUTED\x10\x07\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x08\x12\x10\n\x0cWRONG_ANSWER\x10\t\x12\x18\n\x14VERIFICATION_FAILURE\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\x12\x17\n\x13INTERACTION_FAILURE\x10\x0c\x12\x0b\n\x07\x42LOCKED\x10\r\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x10\n\x0cPROVISIONING\x10\x02\x12\x10\n\x0cINITIALIZING\x10\x03\x12\r\n\tEXECUTING\x10\x04\x12\x0c\n\x08\x43OMPLETE\x10\x05\x12\t\n\x05\x45RROR\x10\x06\x12\n\n\x06\x46\x41ILED\x10\x07\"K\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bTYPE_UPDATE\x10\x01\x12\x0e\n\nTYPE_ERROR\x10\x02\x12\x10\n\x0cTYPE_FAILURE\x10\x03\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.evaluation_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_EVALUATIONREPORT_METADATAENTRY']._loaded_options = None
  _globals['_EVALUATIONREPORT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATIONREPORT']._serialized_start=90
  _globals['_EVALUATIONREPORT']._serialized_end=1435
  _globals['_EVALUATIONREPORT_RUN']._serialized_start=469
  _globals['_EVALUATIONREPORT_RUN']._serialized_end=1177
  _globals['_EVALUATIONREPORT_RUN_STATUS']._serialized_start=936
  _globals['_EVALUATIONREPORT_RUN_STATUS']._serialized_end=1177
  _globals['_EVALUATIONREPORT_METADATAENTRY']._serialized_start=1179
  _globals['_EVALUATIONREPORT_METADATAENTRY']._serialized_end=1226
  _globals['_EVALUATIONREPORT_STATUS']._serialized_start=1229
  _globals['_EVALUATIONREPORT_STATUS']._serialized_end=1358
  _globals['_EVALUATIONREPORT_TYPE']._serialized_start=1360
  _globals['_EVALUATIONREPORT_TYPE']._serialized_end=1435
# @@protoc_insertion_point(module_scope)
