# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/address.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/commerce/address.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/commerce/address.proto\x12\x0f\x65olymp.commerce\"p\n\x07\x41\x64\x64ress\x12\x10\n\x07\x63ountry\x18\xc8\x01 \x01(\t\x12\x0e\n\x05state\x18\xc9\x01 \x01(\t\x12\x14\n\x0bpostal_code\x18\xca\x01 \x01(\t\x12\r\n\x04\x63ity\x18\xcb\x01 \x01(\t\x12\x0e\n\x05line1\x18\xd2\x01 \x01(\t\x12\x0e\n\x05line2\x18\xd3\x01 \x01(\tB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_ADDRESS']._serialized_start=50
  _globals['_ADDRESS']._serialized_end=162
# @@protoc_insertion_point(module_scope)
