# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/judge.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/judge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import announcement_service_pb2 as eolymp_dot_judge_dot_announcement__service__pb2
from eolymp.judge import contest_service_pb2 as eolymp_dot_judge_dot_contest__service__pb2
from eolymp.judge import participant_service_pb2 as eolymp_dot_judge_dot_participant__service__pb2
from eolymp.judge import passcode_service_pb2 as eolymp_dot_judge_dot_passcode__service__pb2
from eolymp.judge import problem_service_pb2 as eolymp_dot_judge_dot_problem__service__pb2
from eolymp.judge import score_service_pb2 as eolymp_dot_judge_dot_score__service__pb2
from eolymp.judge import submission_service_pb2 as eolymp_dot_judge_dot_submission__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/judge/judge.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\'eolymp/judge/announcement_service.proto\x1a\"eolymp/judge/contest_service.proto\x1a&eolymp/judge/participant_service.proto\x1a#eolymp/judge/passcode_service.proto\x1a\"eolymp/judge/problem_service.proto\x1a eolymp/judge/score_service.proto\x1a%eolymp/judge/submission_service.proto2\xcdT\n\x05Judge\x12\x91\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\";\xea\xe2\n\x0b\xf5\xe2\n\n\xd7\xa3=\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x0b\"\t/contests\x12\x9e\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x18*\x16/contests/{contest_id}\x12\x9e\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/contests/{contest_id}\x12\x89\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x12\x16/contests/{contest_id}\x12s\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\x12\t/contests\x12\x9d\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/open\x12\xa1\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/close\x12\xa9\x01\n\x0eSuspendContest\x12!.eolymp.judge.SuspendContestInput\x1a\".eolymp.judge.SuspendContestOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/suspend\x12\xa5\x01\n\rFreezeContest\x12 .eolymp.judge.FreezeContestInput\x1a!.eolymp.judge.FreezeContestOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/freeze\x12\xa5\x01\n\rResumeContest\x12 .eolymp.judge.ResumeContestInput\x1a!.eolymp.judge.ResumeContestOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/resume\x12\xa7\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02!\"\x1f/contests/{contest_id}/problems\x12\xb3\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x33\"1/contests/{contest_id}/problems/{problem_id}/sync\x12\xb4\x01\n\rUpdateProblem\x12 .eolymp.judge.UpdateProblemInput\x1a!.eolymp.judge.UpdateProblemOutput\"^\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02.\",/contests/{contest_id}/problems/{problem_id}\x12\xa3\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02!\x12\x1f/contests/{contest_id}/problems\x12\xba\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"^\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02.\x12,/contests/{contest_id}/problems/{problem_id}\x12\xe0\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.judge.DescribeCodeTemplateInput\x1a(.eolymp.judge.DescribeCodeTemplateOutput\"u\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x46\x12\x44/contests/{contest_id}/problems/{problem_id}/templates/{template_id}\x12\xd2\x01\n\x12LookupCodeTemplate\x12%.eolymp.judge.LookupCodeTemplateInput\x1a&.eolymp.judge.LookupCodeTemplateOutput\"m\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02>\x12</contests/{contest_id}/problems/{problem_id}/lookup-template\x12\xc1\x01\n\x0eListStatements\x12!.eolymp.judge.ListStatementsInput\x1a\".eolymp.judge.ListStatementsOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x39\x12\x37/contests/{contest_id}/problems/{problem_id}/statements\x12\xc5\x01\n\x0fListAttachments\x12\".eolymp.judge.ListAttachmentsInput\x1a#.eolymp.judge.ListAttachmentsOutput\"i\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02:\x12\x38/contests/{contest_id}/problems/{problem_id}/attachments\x12\xb9\x01\n\x0cListExamples\x12\x1f.eolymp.judge.ListExamplesInput\x1a .eolymp.judge.ListExamplesOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x37\x12\x35/contests/{contest_id}/problems/{problem_id}/examples\x12\xb4\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"^\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02.*,/contests/{contest_id}/problems/{problem_id}\x12\xbb\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x35\x12\x33/contests/{contest_id}/problems/{problem_id}/retest\x12\xb7\x01\n\x11\x41ssignParticipant\x12$.eolymp.judge.AssignParticipantInput\x1a%.eolymp.judge.AssignParticipantOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02%\"#/contests/{contest_id}/participants\x12\xcf\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"m\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/participants/{participant_id}/enable\x12\xd3\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"n\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02>\"</contests/{contest_id}/participants/{participant_id}/disable\x12\xc8\x01\n\x11UpdateParticipant\x12$.eolymp.judge.UpdateParticipantInput\x1a%.eolymp.judge.UpdateParticipantOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x36\x1a\x34/contests/{contest_id}/participants/{participant_id}\x12\xc8\x01\n\x11\x44\x65leteParticipant\x12$.eolymp.judge.DeleteParticipantInput\x1a%.eolymp.judge.DeleteParticipantOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x36*4/contests/{contest_id}/participants/{participant_id}\x12\xb3\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02%\x12#/contests/{contest_id}/participants\x12\xce\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"f\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x36\x12\x34/contests/{contest_id}/participants/{participant_id}\x12\x91\x01\n\x0e\x44\x65scribeViewer\x12!.eolymp.judge.DescribeViewerInput\x1a\".eolymp.judge.DescribeViewerOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/introspect\x12\x82\x01\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"2\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/join\x12\xa7\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/start\x12\xb0\x01\n\x0eVerifyPasscode\x12!.eolymp.judge.VerifyPasscodeInput\x1a\".eolymp.judge.VerifyPasscodeOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02(\"&/contests/{contest_id}/verify-passcode\x12\xb3\x01\n\rEnterPasscode\x12 .eolymp.judge.EnterPasscodeInput\x1a!.eolymp.judge.EnterPasscodeOutput\"]\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\'\"%/contests/{contest_id}/enter-passcode\x12\xc5\x01\n\rResetPasscode\x12 .eolymp.judge.ResetPasscodeInput\x1a!.eolymp.judge.ResetPasscodeOutput\"o\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02?\"=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xbf\x01\n\x0bSetPasscode\x12\x1e.eolymp.judge.SetPasscodeInput\x1a\x1f.eolymp.judge.SetPasscodeOutput\"o\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02?\x1a=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xc8\x01\n\x0eRemovePasscode\x12!.eolymp.judge.RemovePasscodeInput\x1a\".eolymp.judge.RemovePasscodeOutput\"o\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02?*=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xcf\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02:\"8/contests/{contest_id}/problems/{problem_id}/submissions\x12\xaf\x01\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02$\x12\"/contests/{contest_id}/submissions\x12\xc8\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x34\x12\x32/contests/{contest_id}/submissions/{submission_id}\x12x\n\x0fWatchSubmission\x12\".eolymp.judge.WatchSubmissionInput\x1a#.eolymp.judge.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xca\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"k\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02;\"9/contests/{contest_id}/submissions/{submission_id}/retest\x12\xc3\x01\n\x10\x44\x65leteSubmission\x12#.eolymp.judge.DeleteSubmissionInput\x1a$.eolymp.judge.DeleteSubmissionOutput\"d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x34*2/contests/{contest_id}/submissions/{submission_id}\x12\xce\x01\n\x11RestoreSubmission\x12$.eolymp.judge.RestoreSubmissionInput\x1a%.eolymp.judge.RestoreSubmissionOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02<\":/contests/{contest_id}/submissions/{submission_id}/restore\x12\xbb\x01\n\x12\x43reateAnnouncement\x12%.eolymp.judge.CreateAnnouncementInput\x1a&.eolymp.judge.CreateAnnouncementOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/contests/{contest_id}/announcements\x12\xcd\x01\n\x12UpdateAnnouncement\x12%.eolymp.judge.UpdateAnnouncementInput\x1a&.eolymp.judge.UpdateAnnouncementOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x38\"6/contests/{contest_id}/announcements/{announcement_id}\x12\xcd\x01\n\x12\x44\x65leteAnnouncement\x12%.eolymp.judge.DeleteAnnouncementInput\x1a&.eolymp.judge.DeleteAnnouncementOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x38*6/contests/{contest_id}/announcements/{announcement_id}\x12\xcb\x01\n\x10ReadAnnouncement\x12#.eolymp.judge.ReadAnnouncementInput\x1a$.eolymp.judge.ReadAnnouncementOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/announcements/{announcement_id}/read\x12\xd2\x01\n\x14\x44\x65scribeAnnouncement\x12\'.eolymp.judge.DescribeAnnouncementInput\x1a(.eolymp.judge.DescribeAnnouncementOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x38\x12\x36/contests/{contest_id}/announcements/{announcement_id}\x12\xeb\x01\n\x1a\x44\x65scribeAnnouncementStatus\x12-.eolymp.judge.DescribeAnnouncementStatusInput\x1a..eolymp.judge.DescribeAnnouncementStatusOutput\"n\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02?\x12=/contests/{contest_id}/announcements/{announcement_id}/status\x12\xb7\x01\n\x11ListAnnouncements\x12$.eolymp.judge.ListAnnouncementsInput\x1a%.eolymp.judge.ListAnnouncementsOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02&\x12$/contests/{contest_id}/announcements\x12\x9a\x01\n\x0fIntrospectScore\x12\".eolymp.judge.IntrospectScoreInput\x1a#.eolymp.judge.IntrospectScoreOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02)\x12\'/contests/{contest_id}/introspect/score\x12\xc2\x01\n\rDescribeScore\x12 .eolymp.judge.DescribeScoreInput\x1a!.eolymp.judge.DescribeScoreOutput\"l\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02<\x12:/contests/{contest_id}/participants/{participant_id}/score\x12\xbd\x01\n\x0bImportScore\x12\x1e.eolymp.judge.ImportScoreInput\x1a\x1f.eolymp.judge.ImportScoreOutput\"m\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/participants/{participant_id}/scores\x12\xbd\x01\n\x0b\x45xportScore\x12\x1e.eolymp.judge.ExportScoreInput\x1a\x1f.eolymp.judge.ExportScoreOutput\"m\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02=\x12;/contests/{contest_id}/participants/{participant_id}/scores\x12\x9d\x01\n\nListResult\x12\x1d.eolymp.judge.ListResultInput\x1a\x1e.eolymp.judge.ListResultOutput\"P\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02 \x12\x1e/contests/{contest_id}/results\x12\xa3\x01\n\x0cRebuildScore\x12\x1f.eolymp.judge.RebuildScoreInput\x1a .eolymp.judge.RebuildScoreOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/rebuild\x12\xab\x01\n\x0eListActivities\x12!.eolymp.judge.ListActivitiesInput\x1a\".eolymp.judge.ListActivitiesOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/activities\x12\x91\x01\n\x14\x44\x65scribeContestUsage\x12\'.eolymp.judge.DescribeContestUsageInput\x1a(.eolymp.judge.DescribeContestUsageOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\x12\x0f/usage/contestsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.judge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_JUDGE'].methods_by_name['CreateContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CreateContest']._serialized_options = b'\352\342\n\013\365\342\n\n\327\243=\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\013\"\t/contests'
  _globals['_JUDGE'].methods_by_name['DeleteContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\030*\026/contests/{contest_id}'
  _globals['_JUDGE'].methods_by_name['UpdateContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\030\032\026/contests/{contest_id}'
  _globals['_JUDGE'].methods_by_name['DescribeContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\030\022\026/contests/{contest_id}'
  _globals['_JUDGE'].methods_by_name['ListContests']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListContests']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\013\022\t/contests'
  _globals['_JUDGE'].methods_by_name['OpenContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['OpenContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\035\"\033/contests/{contest_id}/open'
  _globals['_JUDGE'].methods_by_name['CloseContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CloseContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\036\"\034/contests/{contest_id}/close'
  _globals['_JUDGE'].methods_by_name['SuspendContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['SuspendContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 \"\036/contests/{contest_id}/suspend'
  _globals['_JUDGE'].methods_by_name['FreezeContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['FreezeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\037\"\035/contests/{contest_id}/freeze'
  _globals['_JUDGE'].methods_by_name['ResumeContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ResumeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\037\"\035/contests/{contest_id}/resume'
  _globals['_JUDGE'].methods_by_name['ImportProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ImportProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002!\"\037/contests/{contest_id}/problems'
  _globals['_JUDGE'].methods_by_name['SyncProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['SyncProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0023\"1/contests/{contest_id}/problems/{problem_id}/sync'
  _globals['_JUDGE'].methods_by_name['UpdateProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002.\",/contests/{contest_id}/problems/{problem_id}'
  _globals['_JUDGE'].methods_by_name['ListProblems']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListProblems']._serialized_options = b'\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002!\022\037/contests/{contest_id}/problems'
  _globals['_JUDGE'].methods_by_name['DescribeProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeProblem']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002.\022,/contests/{contest_id}/problems/{problem_id}'
  _globals['_JUDGE'].methods_by_name['DescribeCodeTemplate']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002F\022D/contests/{contest_id}/problems/{problem_id}/templates/{template_id}'
  _globals['_JUDGE'].methods_by_name['LookupCodeTemplate']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['LookupCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002>\022</contests/{contest_id}/problems/{problem_id}/lookup-template'
  _globals['_JUDGE'].methods_by_name['ListStatements']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListStatements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0029\0227/contests/{contest_id}/problems/{problem_id}/statements'
  _globals['_JUDGE'].methods_by_name['ListAttachments']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListAttachments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002:\0228/contests/{contest_id}/problems/{problem_id}/attachments'
  _globals['_JUDGE'].methods_by_name['ListExamples']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListExamples']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0027\0225/contests/{contest_id}/problems/{problem_id}/examples'
  _globals['_JUDGE'].methods_by_name['DeleteProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002.*,/contests/{contest_id}/problems/{problem_id}'
  _globals['_JUDGE'].methods_by_name['RetestProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RetestProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0025\0223/contests/{contest_id}/problems/{problem_id}/retest'
  _globals['_JUDGE'].methods_by_name['AssignParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['AssignParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002%\"#/contests/{contest_id}/participants'
  _globals['_JUDGE'].methods_by_name['EnableParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['EnableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002=\";/contests/{contest_id}/participants/{participant_id}/enable'
  _globals['_JUDGE'].methods_by_name['DisableParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DisableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002>\"</contests/{contest_id}/participants/{participant_id}/disable'
  _globals['_JUDGE'].methods_by_name['UpdateParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0026\0324/contests/{contest_id}/participants/{participant_id}'
  _globals['_JUDGE'].methods_by_name['DeleteParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0026*4/contests/{contest_id}/participants/{participant_id}'
  _globals['_JUDGE'].methods_by_name['ListParticipants']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListParticipants']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002%\022#/contests/{contest_id}/participants'
  _globals['_JUDGE'].methods_by_name['DescribeParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeParticipant']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0026\0224/contests/{contest_id}/participants/{participant_id}'
  _globals['_JUDGE'].methods_by_name['DescribeViewer']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeViewer']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002#\022!/contests/{contest_id}/introspect'
  _globals['_JUDGE'].methods_by_name['JoinContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['JoinContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\035\"\033/contests/{contest_id}/join'
  _globals['_JUDGE'].methods_by_name['StartContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['StartContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\036\"\034/contests/{contest_id}/start'
  _globals['_JUDGE'].methods_by_name['VerifyPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['VerifyPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002(\"&/contests/{contest_id}/verify-passcode'
  _globals['_JUDGE'].methods_by_name['EnterPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['EnterPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\'\"%/contests/{contest_id}/enter-passcode'
  _globals['_JUDGE'].methods_by_name['ResetPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ResetPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002?\"=/contests/{contest_id}/participants/{participant_id}/passcode'
  _globals['_JUDGE'].methods_by_name['SetPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['SetPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002?\032=/contests/{contest_id}/participants/{participant_id}/passcode'
  _globals['_JUDGE'].methods_by_name['RemovePasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RemovePasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002?*=/contests/{contest_id}/participants/{participant_id}/passcode'
  _globals['_JUDGE'].methods_by_name['CreateSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CreateSubmission']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002:\"8/contests/{contest_id}/problems/{problem_id}/submissions'
  _globals['_JUDGE'].methods_by_name['ListSubmissions']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListSubmissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002$\022\"/contests/{contest_id}/submissions'
  _globals['_JUDGE'].methods_by_name['DescribeSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0024\0222/contests/{contest_id}/submissions/{submission_id}'
  _globals['_JUDGE'].methods_by_name['WatchSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_JUDGE'].methods_by_name['RetestSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RetestSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002;\"9/contests/{contest_id}/submissions/{submission_id}/retest'
  _globals['_JUDGE'].methods_by_name['DeleteSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0024*2/contests/{contest_id}/submissions/{submission_id}'
  _globals['_JUDGE'].methods_by_name['RestoreSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RestoreSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002<\":/contests/{contest_id}/submissions/{submission_id}/restore'
  _globals['_JUDGE'].methods_by_name['CreateAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CreateAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/contests/{contest_id}/announcements'
  _globals['_JUDGE'].methods_by_name['UpdateAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0028\"6/contests/{contest_id}/announcements/{announcement_id}'
  _globals['_JUDGE'].methods_by_name['DeleteAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0028*6/contests/{contest_id}/announcements/{announcement_id}'
  _globals['_JUDGE'].methods_by_name['ReadAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ReadAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002=\";/contests/{contest_id}/announcements/{announcement_id}/read'
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0028\0226/contests/{contest_id}/announcements/{announcement_id}'
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncementStatus']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncementStatus']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002?\022=/contests/{contest_id}/announcements/{announcement_id}/status'
  _globals['_JUDGE'].methods_by_name['ListAnnouncements']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListAnnouncements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002&\022$/contests/{contest_id}/announcements'
  _globals['_JUDGE'].methods_by_name['IntrospectScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['IntrospectScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002)\022\'/contests/{contest_id}/introspect/score'
  _globals['_JUDGE'].methods_by_name['DescribeScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002<\022:/contests/{contest_id}/participants/{participant_id}/score'
  _globals['_JUDGE'].methods_by_name['ImportScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ImportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002=\";/contests/{contest_id}/participants/{participant_id}/scores'
  _globals['_JUDGE'].methods_by_name['ExportScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ExportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002=\022;/contests/{contest_id}/participants/{participant_id}/scores'
  _globals['_JUDGE'].methods_by_name['ListResult']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListResult']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002 \022\036/contests/{contest_id}/results'
  _globals['_JUDGE'].methods_by_name['RebuildScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RebuildScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 \"\036/contests/{contest_id}/rebuild'
  _globals['_JUDGE'].methods_by_name['ListActivities']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListActivities']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002#\022!/contests/{contest_id}/activities'
  _globals['_JUDGE'].methods_by_name['DescribeContestUsage']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeContestUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\021\022\017/usage/contests'
  _globals['_JUDGE']._serialized_start=405
  _globals['_JUDGE']._serialized_end=11234
# @@protoc_insertion_point(module_scope)
