# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/editorial.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/editorial.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/atlas/editorial.proto\x12\x0c\x65olymp.atlas\x1a\x18\x65olymp/ecm/content.proto\"\xfc\x02\n\tEditorial\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x11\n\tautomatic\x18\x08 \x01(\x08\x12\r\n\x05\x64raft\x18\n \x01(\x08\x12$\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x15\n\rdownload_link\x18\x07 \x01(\t\x12\x11\n\tauthor_id\x18g \x01(\t\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\"\xa2\x01\n\x05Patch\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\r\n\tPATCH_ALL\x10\x01\x12\x10\n\x0cPATCH_LOCALE\x10\x02\x12\x13\n\x0fPATCH_AUTOMATIC\x10\x03\x12\x0f\n\x0bPATCH_DRAFT\x10\x04\x12\x11\n\rPATCH_CONTENT\x10\x05\x12\x17\n\x13PATCH_DOWNLOAD_LINK\x10\x06\x12\x13\n\x0fPATCH_AUTHOR_ID\x10\x07\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.editorial_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_EDITORIAL']._serialized_start=73
  _globals['_EDITORIAL']._serialized_end=453
  _globals['_EDITORIAL_EXTRA']._serialized_start=228
  _globals['_EDITORIAL_EXTRA']._serialized_end=288
  _globals['_EDITORIAL_PATCH']._serialized_start=291
  _globals['_EDITORIAL_PATCH']._serialized_end=453
# @@protoc_insertion_point(module_scope)
