# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/helpdesk/support.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/helpdesk/support.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.helpdesk import auto_reply_service_pb2 as eolymp_dot_helpdesk_dot_auto__reply__service__pb2
from eolymp.helpdesk import ticket_service_pb2 as eolymp_dot_helpdesk_dot_ticket__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/helpdesk/support.proto\x12\x0f\x65olymp.helpdesk\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a(eolymp/helpdesk/auto_reply_service.proto\x1a$eolymp/helpdesk/ticket_service.proto2\xfd\x1a\n\x07Support\x12\x9e\x01\n\x0c\x43reateTicket\x12\".eolymp.helpdesk.CreateTicketInput\x1a#.eolymp.helpdesk.CreateTicketOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x13\"\x11/helpdesk/tickets\x12\xaa\x01\n\x0cUpdateTicket\x12\".eolymp.helpdesk.UpdateTicketInput\x1a#.eolymp.helpdesk.UpdateTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/helpdesk/tickets/{ticket_id}\x12\xaa\x01\n\x0c\x44\x65leteTicket\x12\".eolymp.helpdesk.DeleteTicketInput\x1a#.eolymp.helpdesk.DeleteTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f*\x1d/helpdesk/tickets/{ticket_id}\x12\xaf\x01\n\x0e\x44\x65scribeTicket\x12$.eolymp.helpdesk.DescribeTicketInput\x1a%.eolymp.helpdesk.DescribeTicketOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/helpdesk/tickets/{ticket_id}\x12\x9a\x01\n\x0bListTickets\x12!.eolymp.helpdesk.ListTicketsInput\x1a\".eolymp.helpdesk.ListTicketsOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x13\x12\x11/helpdesk/tickets\x12\xb5\x01\n\rApproveTicket\x12#.eolymp.helpdesk.ApproveTicketInput\x1a$.eolymp.helpdesk.ApproveTicketOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\'\"%/helpdesk/tickets/{ticket_id}/approve\x12\xb1\x01\n\x0cRejectTicket\x12\".eolymp.helpdesk.RejectTicketInput\x1a#.eolymp.helpdesk.RejectTicketOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02&\"$/helpdesk/tickets/{ticket_id}/reject\x12\xad\x01\n\x0b\x43loseTicket\x12!.eolymp.helpdesk.CloseTicketInput\x1a\".eolymp.helpdesk.CloseTicketOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02%\"#/helpdesk/tickets/{ticket_id}/close\x12\xad\x01\n\nAddComment\x12 .eolymp.helpdesk.AddCommentInput\x1a!.eolymp.helpdesk.AddCommentOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02(\"&/helpdesk/tickets/{ticket_id}/comments\x12\xc3\x01\n\rUpdateComment\x12#.eolymp.helpdesk.UpdateCommentInput\x1a$.eolymp.helpdesk.UpdateCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x1a\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xc3\x01\n\rDeleteComment\x12#.eolymp.helpdesk.DeleteCommentInput\x1a$.eolymp.helpdesk.DeleteCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xb2\x01\n\x0cListComments\x12\".eolymp.helpdesk.ListCommentsInput\x1a#.eolymp.helpdesk.ListCommentsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02(\x12&/helpdesk/tickets/{ticket_id}/comments\x12\xc9\x01\n\x0f\x44\x65scribeComment\x12%.eolymp.helpdesk.DescribeCommentInput\x1a&.eolymp.helpdesk.DescribeCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x12\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xaf\x01\n\x0f\x43reateAutoReply\x12%.eolymp.helpdesk.CreateAutoReplyInput\x1a&.eolymp.helpdesk.CreateAutoReplyOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\x17\"\x15/helpdesk/autoreplies\x12\xba\x01\n\x0fUpdateAutoReply\x12%.eolymp.helpdesk.UpdateAutoReplyInput\x1a&.eolymp.helpdesk.UpdateAutoReplyOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\"\x1a /helpdesk/autoreplies/{reply_id}\x12\xba\x01\n\x0f\x44\x65leteAutoReply\x12%.eolymp.helpdesk.DeleteAutoReplyInput\x1a&.eolymp.helpdesk.DeleteAutoReplyOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\"* /helpdesk/autoreplies/{reply_id}\x12\xae\x01\n\x0fListAutoReplies\x12%.eolymp.helpdesk.ListAutoRepliesInput\x1a&.eolymp.helpdesk.ListAutoRepliesOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1c\x8a\xe3\n\x18helpdesk:auto-reply:read\x82\xd3\xe4\x93\x02\x17\x12\x15/helpdesk/autoreplies\x12\xc0\x01\n\x11\x44\x65scribeAutoReply\x12\'.eolymp.helpdesk.DescribeAutoReplyInput\x1a(.eolymp.helpdesk.DescribeAutoReplyOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\"\x12 /helpdesk/autoreplies/{reply_id}\x12\xae\x01\n\x10UploadAttachment\x12&.eolymp.helpdesk.UploadAttachmentInput\x1a\'.eolymp.helpdesk.UploadAttachmentOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x17\"\x15/helpdesk/attachmentsB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.support_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _globals['_SUPPORT'].methods_by_name['CreateTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['CreateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\023\"\021/helpdesk/tickets'
  _globals['_SUPPORT'].methods_by_name['UpdateTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UpdateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037\032\035/helpdesk/tickets/{ticket_id}'
  _globals['_SUPPORT'].methods_by_name['DeleteTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DeleteTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037*\035/helpdesk/tickets/{ticket_id}'
  _globals['_SUPPORT'].methods_by_name['DescribeTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DescribeTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\037\022\035/helpdesk/tickets/{ticket_id}'
  _globals['_SUPPORT'].methods_by_name['ListTickets']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ListTickets']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\023\022\021/helpdesk/tickets'
  _globals['_SUPPORT'].methods_by_name['ApproveTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ApproveTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\'\"%/helpdesk/tickets/{ticket_id}/approve'
  _globals['_SUPPORT'].methods_by_name['RejectTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['RejectTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002&\"$/helpdesk/tickets/{ticket_id}/reject'
  _globals['_SUPPORT'].methods_by_name['CloseTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['CloseTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002%\"#/helpdesk/tickets/{ticket_id}/close'
  _globals['_SUPPORT'].methods_by_name['AddComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['AddComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002(\"&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_SUPPORT'].methods_by_name['UpdateComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UpdateComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0323/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_SUPPORT'].methods_by_name['DeleteComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DeleteComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_SUPPORT'].methods_by_name['ListComments']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ListComments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002(\022&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_SUPPORT'].methods_by_name['DescribeComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DescribeComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0223/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_SUPPORT'].methods_by_name['CreateAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['CreateAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\027\"\025/helpdesk/autoreplies'
  _globals['_SUPPORT'].methods_by_name['UpdateAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UpdateAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\"\032 /helpdesk/autoreplies/{reply_id}'
  _globals['_SUPPORT'].methods_by_name['DeleteAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DeleteAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\"* /helpdesk/autoreplies/{reply_id}'
  _globals['_SUPPORT'].methods_by_name['ListAutoReplies']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ListAutoReplies']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\034\212\343\n\030helpdesk:auto-reply:read\202\323\344\223\002\027\022\025/helpdesk/autoreplies'
  _globals['_SUPPORT'].methods_by_name['DescribeAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DescribeAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\"\022 /helpdesk/autoreplies/{reply_id}'
  _globals['_SUPPORT'].methods_by_name['UploadAttachment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UploadAttachment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\027\"\025/helpdesk/attachments'
  _globals['_SUPPORT']._serialized_start=230
  _globals['_SUPPORT']._serialized_end=3683
# @@protoc_insertion_point(module_scope)
