# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/wellknown/errors.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/wellknown/errors.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/wellknown/errors.proto\x12\x10\x65olymp.wellknown\" \n\x0b\x45rrorReport\x12\x11\n\treport_id\x18\x01 \x01(\t\"Z\n\x0fInvalidArgument\x12\x15\n\rargument_path\x18\x01 \x01(\t\x12\x30\n\nvalidation\x18\x02 \x03(\x0b\x32\x1c.eolymp.wellknown.Validation\"u\n\nValidation\x12\x15\n\rargument_path\x18\x01 \x03(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x39\n\x0clocalization\x18\x03 \x01(\x0b\x32#.eolymp.wellknown.ErrorLocalization\"-\n\rQuotaExceeded\x12\r\n\x05quota\x18\x01 \x01(\x05\x12\r\n\x05usage\x18\x02 \x01(\x05\"\xaa\x01\n\x11\x45rrorLocalization\x12\x12\n\nphrase_key\x18\x01 \x01(\t\x12L\n\rphrase_params\x18\x02 \x03(\x0b\x32\x35.eolymp.wellknown.ErrorLocalization.PhraseParamsEntry\x1a\x33\n\x11PhraseParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknownb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.wellknown.errors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknown'
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._loaded_options = None
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ERRORREPORT']._serialized_start=51
  _globals['_ERRORREPORT']._serialized_end=83
  _globals['_INVALIDARGUMENT']._serialized_start=85
  _globals['_INVALIDARGUMENT']._serialized_end=175
  _globals['_VALIDATION']._serialized_start=177
  _globals['_VALIDATION']._serialized_end=294
  _globals['_QUOTAEXCEEDED']._serialized_start=296
  _globals['_QUOTAEXCEEDED']._serialized_end=341
  _globals['_ERRORLOCALIZATION']._serialized_start=344
  _globals['_ERRORLOCALIZATION']._serialized_end=514
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._serialized_start=463
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._serialized_end=514
# @@protoc_insertion_point(module_scope)
