# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/fragment.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/content/fragment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/content/fragment.proto\x12\x0e\x65olymp.content\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x03\n\x08\x46ragment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x0b \x01(\t\x12\r\n\x05\x64raft\x18\r \x01(\x08\x12\r\n\x05title\x18\x0c \x01(\t\x12$\n\x07\x63ontent\x18\x33 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12.\n\ncreated_at\x18< \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18= \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06labels\x18\x64 \x03(\t\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\"\x92\x01\n\x05Patch\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\r\n\tPATCH_ALL\x10\x01\x12\x0e\n\nPATCH_PATH\x10\x02\x12\x10\n\x0cPATCH_LOCALE\x10\x03\x12\x0f\n\x0bPATCH_DRAFT\x10\x05\x12\x0f\n\x0bPATCH_TITLE\x10\x06\x12\x11\n\rPATCH_CONTENT\x10\x07\x12\x10\n\x0cPATCH_LABELS\x10\x08\x42\x31Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.fragment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_FRAGMENT']._serialized_start=109
  _globals['_FRAGMENT']._serialized_end=552
  _globals['_FRAGMENT_EXTRA']._serialized_start=343
  _globals['_FRAGMENT_EXTRA']._serialized_end=403
  _globals['_FRAGMENT_PATCH']._serialized_start=406
  _globals['_FRAGMENT_PATCH']._serialized_end=552
# @@protoc_insertion_point(module_scope)
