# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/participant.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/participant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import medal_pb2 as eolymp_dot_judge_dot_medal__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/judge/participant.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/judge/medal.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x04\n\x0bParticipant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\t\x12\x12\n\nunofficial\x18\x06 \x01(\x08\x12\x10\n\x08inactive\x18\n \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x0b \x01(\x08\x12\r\n\x05ghost\x18\x08 \x01(\x08\x12\"\n\x05medal\x18\t \x01(\x0e\x32\x13.eolymp.judge.Medal\x12\x30\n\x06status\x18\x14 \x01(\x0e\x32 .eolymp.judge.Participant.Status\x12.\n\nstarted_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstarted_in\x18\x16 \x01(\r\x12*\n\x06\x65nd_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x65nd_in\x18\x1a \x01(\r\x12\x12\n\nbonus_time\x18\x1b \x01(\r\x12\x10\n\x08passcode\x18\x1e \x01(\t\x12\x31\n\x07submits\x18( \x03(\x0b\x32 .eolymp.judge.Participant.Submit\x1a-\n\x06Submit\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\r\"h\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07WAITING\x10\x05\x12\t\n\x05READY\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\x0b\n\x07UPSOLVE\x10\x07\x12\x0b\n\x07\x42LOCKED\x10\x08\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.participant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PARTICIPANT']._serialized_start=108
  _globals['_PARTICIPANT']._serialized_end=705
  _globals['_PARTICIPANT_SUBMIT']._serialized_start=554
  _globals['_PARTICIPANT_SUBMIT']._serialized_end=599
  _globals['_PARTICIPANT_STATUS']._serialized_start=601
  _globals['_PARTICIPANT_STATUS']._serialized_end=705
# @@protoc_insertion_point(module_scope)
