# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/testing_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/testing_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import testing_checker_pb2 as eolymp_dot_atlas_dot_testing__checker__pb2
from eolymp.atlas import testing_config_pb2 as eolymp_dot_atlas_dot_testing__config__pb2
from eolymp.atlas import testing_interactor_pb2 as eolymp_dot_atlas_dot_testing__interactor__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.atlas import testing_testset_pb2 as eolymp_dot_atlas_dot_testing__testset__pb2
from eolymp.atlas import testing_validator_pb2 as eolymp_dot_atlas_dot_testing__validator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/atlas/testing_checker.proto\x1a!eolymp/atlas/testing_config.proto\x1a%eolymp/atlas/testing_interactor.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a\"eolymp/atlas/testing_testset.proto\x1a$eolymp/atlas/testing_validator.proto\"\x88\x01\n\x19TestingConfigChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12+\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\x12*\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"\x7f\n\x16InteractorChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\x12\'\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"v\n\x13\x43heckerChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12%\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Checker\x12$\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"|\n\x15ValidatorChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\'\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Validator\x12&\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Validator\"v\n\x13TestsetChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12%\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x12$\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"m\n\x10TestChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\"\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\x12!\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x12.eolymp.atlas.Test\"r\n\x15TestBatchChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\"\n\x06\x62\x65\x66ore\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\x12!\n\x05\x61\x66ter\x18\x03 \x03(\x0b\x32\x12.eolymp.atlas.Test\"G\n\x18UpdateTestingConfigInput\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"\x1b\n\x19UpdateTestingConfigOutput\"-\n\x1a\x44\x65scribeTestingConfigInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"J\n\x1b\x44\x65scribeTestingConfigOutput\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"<\n\x12UpdateCheckerInput\x12&\n\x07\x63hecker\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"\x15\n\x13UpdateCheckerOutput\"\'\n\x14\x44\x65scribeCheckerInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"?\n\x15\x44\x65scribeCheckerOutput\x12&\n\x07\x63hecker\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"E\n\x15UpdateInteractorInput\x12,\n\ninteractor\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"\x18\n\x16UpdateInteractorOutput\"*\n\x17\x44\x65scribeInteractorInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"H\n\x18\x44\x65scribeInteractorOutput\x12,\n\ninteractor\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"B\n\x14UpdateValidatorInput\x12*\n\tvalidator\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Validator\"\x17\n\x15UpdateValidatorOutput\")\n\x16\x44\x65scribeValidatorInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"E\n\x17\x44\x65scribeValidatorOutput\x12*\n\tvalidator\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Validator\"B\n\x11ListTestsetsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0f\n\x07version\x18\x64 \x01(\r\"I\n\x12ListTestsetsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Testset\";\n\x14\x44\x65scribeTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"?\n\x15\x44\x65scribeTestsetOutput\x12&\n\x07testset\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"<\n\x12\x43reateTestsetInput\x12&\n\x07testset\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"!\n\x13\x43reateTestsetOutput\x12\n\n\x02id\x18\x01 \x01(\t\"P\n\x12UpdateTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12&\n\x07testset\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"\x15\n\x13UpdateTestsetOutput\"(\n\x12\x44\x65leteTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteTestsetOutput\"$\n\x11ListExamplesInput\x12\x0f\n\x07version\x18\x64 \x01(\r\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"5\n\x0eListTestsInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"C\n\x0fListTestsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"I\n\x11\x44\x65scribeTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"6\n\x12\x44\x65scribeTestOutput\x12 \n\x04test\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\"G\n\x0f\x43reateTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12 \n\x04test\x18\x03 \x01(\x0b\x32\x12.eolymp.atlas.Test\"#\n\x10\x43reateTestOutput\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"\x9a\x02\n\x0fUpdateTestInput\x12\x32\n\x05patch\x18\x05 \x03(\x0e\x32#.eolymp.atlas.UpdateTestInput.Patch\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12 \n\x04test\x18\x04 \x01(\x0b\x32\x12.eolymp.atlas.Test\"\x8b\x01\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x45XAMPLE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\t\n\x05SCORE\x10\x03\x12\t\n\x05INPUT\x10\x04\x12\n\n\x06\x41NSWER\x10\x05\x12\t\n\x05INDEX\x10\x08\x12\n\n\x06SECRET\x10\t\x12\x11\n\rEXAMPLE_INPUT\x10\x06\x12\x12\n\x0e\x45XAMPLE_ANSWER\x10\x07\"\x12\n\x10UpdateTestOutput\"6\n\x0f\x44\x65leteTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\"\x12\n\x10\x44\x65leteTestOutput2\xe4\x17\n\x0eTestingService\x12\xa2\x01\n\x13UpdateTestingConfig\x12&.eolymp.atlas.UpdateTestingConfigInput\x1a\'.eolymp.atlas.UpdateTestingConfigOutput\":\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x1a\x08/testing\x12\xa8\x01\n\x15\x44\x65scribeTestingConfig\x12(.eolymp.atlas.DescribeTestingConfigInput\x1a).eolymp.atlas.DescribeTestingConfigOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x12\x08/testing\x12\x90\x01\n\rUpdateChecker\x12 .eolymp.atlas.UpdateCheckerInput\x1a!.eolymp.atlas.UpdateCheckerOutput\":\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x1a\x08/checker\x12\x96\x01\n\x0f\x44\x65scribeChecker\x12\".eolymp.atlas.DescribeCheckerInput\x1a#.eolymp.atlas.DescribeCheckerOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x12\x08/checker\x12\x9c\x01\n\x10UpdateInteractor\x12#.eolymp.atlas.UpdateInteractorInput\x1a$.eolymp.atlas.UpdateInteractorOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\r\x1a\x0b/interactor\x12\xa2\x01\n\x12\x44\x65scribeInteractor\x12%.eolymp.atlas.DescribeInteractorInput\x1a&.eolymp.atlas.DescribeInteractorOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\r\x12\x0b/interactor\x12\x98\x01\n\x0fUpdateValidator\x12\".eolymp.atlas.UpdateValidatorInput\x1a#.eolymp.atlas.UpdateValidatorOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0c\x1a\n/validator\x12\x9e\x01\n\x11\x44\x65scribeValidator\x12$.eolymp.atlas.DescribeValidatorInput\x1a%.eolymp.atlas.DescribeValidatorOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0c\x12\n/validator\x12\x91\x01\n\rCreateTestset\x12 .eolymp.atlas.CreateTestsetInput\x1a!.eolymp.atlas.CreateTestsetOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0b\"\t/testsets\x12\x9e\x01\n\rUpdateTestset\x12 .eolymp.atlas.UpdateTestsetInput\x1a!.eolymp.atlas.UpdateTestsetOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/testsets/{testset_id}\x12\x9e\x01\n\rDeleteTestset\x12 .eolymp.atlas.DeleteTestsetInput\x1a!.eolymp.atlas.DeleteTestsetOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18*\x16/testsets/{testset_id}\x12\xa4\x01\n\x0f\x44\x65scribeTestset\x12\".eolymp.atlas.DescribeTestsetInput\x1a#.eolymp.atlas.DescribeTestsetOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18\x12\x16/testsets/{testset_id}\x12\x8e\x01\n\x0cListTestsets\x12\x1f.eolymp.atlas.ListTestsetsInput\x1a .eolymp.atlas.ListTestsetsOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0b\x12\t/testsets\x12\x9c\x01\n\nCreateTest\x12\x1d.eolymp.atlas.CreateTestInput\x1a\x1e.eolymp.atlas.CreateTestOutput\"O\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/testsets/{testset_id}/tests\x12\xa6\x01\n\nUpdateTest\x12\x1d.eolymp.atlas.UpdateTestInput\x1a\x1e.eolymp.atlas.UpdateTestOutput\"Y\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02(\x1a&/testsets/{testset_id}/tests/{test_id}\x12\xa6\x01\n\nDeleteTest\x12\x1d.eolymp.atlas.DeleteTestInput\x1a\x1e.eolymp.atlas.DeleteTestOutput\"Y\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02(*&/testsets/{testset_id}/tests/{test_id}\x12\xab\x01\n\x0c\x44\x65scribeTest\x12\x1f.eolymp.atlas.DescribeTestInput\x1a .eolymp.atlas.DescribeTestOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02(\x12&/testsets/{testset_id}/tests/{test_id}\x12\x98\x01\n\tListTests\x12\x1c.eolymp.atlas.ListTestsInput\x1a\x1d.eolymp.atlas.ListTestsOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1e\x12\x1c/testsets/{testset_id}/tests\x12\x8d\x01\n\x0cListExamples\x12\x1f.eolymp.atlas.ListExamplesInput\x1a .eolymp.atlas.ListExamplesOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0b\x12\t/examplesB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestingConfig']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestingConfig']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\032\010/testing'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestingConfig']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestingConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\022\010/testing'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateChecker']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateChecker']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\032\010/checker'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeChecker']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeChecker']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\022\010/checker'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateInteractor']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateInteractor']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\r\032\013/interactor'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeInteractor']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeInteractor']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\r\022\013/interactor'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateValidator']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateValidator']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\014\032\n/validator'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeValidator']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeValidator']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\014\022\n/validator'
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\013\"\t/testsets'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030\032\026/testsets/{testset_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030*\026/testsets/{testset_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030\022\026/testsets/{testset_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['ListTestsets']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['ListTestsets']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\013\022\t/testsets'
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTest']._serialized_options = b'\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\036\"\034/testsets/{testset_id}/tests'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTest']._serialized_options = b'\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002(\032&/testsets/{testset_id}/tests/{test_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTest']._serialized_options = b'\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002(*&/testsets/{testset_id}/tests/{test_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002(\022&/testsets/{testset_id}/tests/{test_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['ListTests']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['ListTests']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\036\022\034/testsets/{testset_id}/tests'
  _globals['_TESTINGSERVICE'].methods_by_name['ListExamples']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['ListExamples']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\013\022\t/examples'
  _globals['_TESTINGCONFIGCHANGEDEVENT']._serialized_start=369
  _globals['_TESTINGCONFIGCHANGEDEVENT']._serialized_end=505
  _globals['_INTERACTORCHANGEDEVENT']._serialized_start=507
  _globals['_INTERACTORCHANGEDEVENT']._serialized_end=634
  _globals['_CHECKERCHANGEDEVENT']._serialized_start=636
  _globals['_CHECKERCHANGEDEVENT']._serialized_end=754
  _globals['_VALIDATORCHANGEDEVENT']._serialized_start=756
  _globals['_VALIDATORCHANGEDEVENT']._serialized_end=880
  _globals['_TESTSETCHANGEDEVENT']._serialized_start=882
  _globals['_TESTSETCHANGEDEVENT']._serialized_end=1000
  _globals['_TESTCHANGEDEVENT']._serialized_start=1002
  _globals['_TESTCHANGEDEVENT']._serialized_end=1111
  _globals['_TESTBATCHCHANGEDEVENT']._serialized_start=1113
  _globals['_TESTBATCHCHANGEDEVENT']._serialized_end=1227
  _globals['_UPDATETESTINGCONFIGINPUT']._serialized_start=1229
  _globals['_UPDATETESTINGCONFIGINPUT']._serialized_end=1300
  _globals['_UPDATETESTINGCONFIGOUTPUT']._serialized_start=1302
  _globals['_UPDATETESTINGCONFIGOUTPUT']._serialized_end=1329
  _globals['_DESCRIBETESTINGCONFIGINPUT']._serialized_start=1331
  _globals['_DESCRIBETESTINGCONFIGINPUT']._serialized_end=1376
  _globals['_DESCRIBETESTINGCONFIGOUTPUT']._serialized_start=1378
  _globals['_DESCRIBETESTINGCONFIGOUTPUT']._serialized_end=1452
  _globals['_UPDATECHECKERINPUT']._serialized_start=1454
  _globals['_UPDATECHECKERINPUT']._serialized_end=1514
  _globals['_UPDATECHECKEROUTPUT']._serialized_start=1516
  _globals['_UPDATECHECKEROUTPUT']._serialized_end=1537
  _globals['_DESCRIBECHECKERINPUT']._serialized_start=1539
  _globals['_DESCRIBECHECKERINPUT']._serialized_end=1578
  _globals['_DESCRIBECHECKEROUTPUT']._serialized_start=1580
  _globals['_DESCRIBECHECKEROUTPUT']._serialized_end=1643
  _globals['_UPDATEINTERACTORINPUT']._serialized_start=1645
  _globals['_UPDATEINTERACTORINPUT']._serialized_end=1714
  _globals['_UPDATEINTERACTOROUTPUT']._serialized_start=1716
  _globals['_UPDATEINTERACTOROUTPUT']._serialized_end=1740
  _globals['_DESCRIBEINTERACTORINPUT']._serialized_start=1742
  _globals['_DESCRIBEINTERACTORINPUT']._serialized_end=1784
  _globals['_DESCRIBEINTERACTOROUTPUT']._serialized_start=1786
  _globals['_DESCRIBEINTERACTOROUTPUT']._serialized_end=1858
  _globals['_UPDATEVALIDATORINPUT']._serialized_start=1860
  _globals['_UPDATEVALIDATORINPUT']._serialized_end=1926
  _globals['_UPDATEVALIDATOROUTPUT']._serialized_start=1928
  _globals['_UPDATEVALIDATOROUTPUT']._serialized_end=1951
  _globals['_DESCRIBEVALIDATORINPUT']._serialized_start=1953
  _globals['_DESCRIBEVALIDATORINPUT']._serialized_end=1994
  _globals['_DESCRIBEVALIDATOROUTPUT']._serialized_start=1996
  _globals['_DESCRIBEVALIDATOROUTPUT']._serialized_end=2065
  _globals['_LISTTESTSETSINPUT']._serialized_start=2067
  _globals['_LISTTESTSETSINPUT']._serialized_end=2133
  _globals['_LISTTESTSETSOUTPUT']._serialized_start=2135
  _globals['_LISTTESTSETSOUTPUT']._serialized_end=2208
  _globals['_DESCRIBETESTSETINPUT']._serialized_start=2210
  _globals['_DESCRIBETESTSETINPUT']._serialized_end=2269
  _globals['_DESCRIBETESTSETOUTPUT']._serialized_start=2271
  _globals['_DESCRIBETESTSETOUTPUT']._serialized_end=2334
  _globals['_CREATETESTSETINPUT']._serialized_start=2336
  _globals['_CREATETESTSETINPUT']._serialized_end=2396
  _globals['_CREATETESTSETOUTPUT']._serialized_start=2398
  _globals['_CREATETESTSETOUTPUT']._serialized_end=2431
  _globals['_UPDATETESTSETINPUT']._serialized_start=2433
  _globals['_UPDATETESTSETINPUT']._serialized_end=2513
  _globals['_UPDATETESTSETOUTPUT']._serialized_start=2515
  _globals['_UPDATETESTSETOUTPUT']._serialized_end=2536
  _globals['_DELETETESTSETINPUT']._serialized_start=2538
  _globals['_DELETETESTSETINPUT']._serialized_end=2578
  _globals['_DELETETESTSETOUTPUT']._serialized_start=2580
  _globals['_DELETETESTSETOUTPUT']._serialized_end=2601
  _globals['_LISTEXAMPLESINPUT']._serialized_start=2603
  _globals['_LISTEXAMPLESINPUT']._serialized_end=2639
  _globals['_LISTEXAMPLESOUTPUT']._serialized_start=2641
  _globals['_LISTEXAMPLESOUTPUT']._serialized_end=2699
  _globals['_LISTTESTSINPUT']._serialized_start=2701
  _globals['_LISTTESTSINPUT']._serialized_end=2754
  _globals['_LISTTESTSOUTPUT']._serialized_start=2756
  _globals['_LISTTESTSOUTPUT']._serialized_end=2823
  _globals['_DESCRIBETESTINPUT']._serialized_start=2825
  _globals['_DESCRIBETESTINPUT']._serialized_end=2898
  _globals['_DESCRIBETESTOUTPUT']._serialized_start=2900
  _globals['_DESCRIBETESTOUTPUT']._serialized_end=2954
  _globals['_CREATETESTINPUT']._serialized_start=2956
  _globals['_CREATETESTINPUT']._serialized_end=3027
  _globals['_CREATETESTOUTPUT']._serialized_start=3029
  _globals['_CREATETESTOUTPUT']._serialized_end=3064
  _globals['_UPDATETESTINPUT']._serialized_start=3067
  _globals['_UPDATETESTINPUT']._serialized_end=3349
  _globals['_UPDATETESTINPUT_PATCH']._serialized_start=3210
  _globals['_UPDATETESTINPUT_PATCH']._serialized_end=3349
  _globals['_UPDATETESTOUTPUT']._serialized_start=3351
  _globals['_UPDATETESTOUTPUT']._serialized_end=3369
  _globals['_DELETETESTINPUT']._serialized_start=3371
  _globals['_DELETETESTINPUT']._serialized_end=3425
  _globals['_DELETETESTOUTPUT']._serialized_start=3427
  _globals['_DELETETESTOUTPUT']._serialized_end=3445
  _globals['_TESTINGSERVICE']._serialized_start=3448
  _globals['_TESTINGSERVICE']._serialized_end=6492
# @@protoc_insertion_point(module_scope)
