# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/runtime/runtime_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/runtime/runtime_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.runtime import language_pb2 as eolymp_dot_runtime_dot_language__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/runtime/runtime_service.proto\x12\x0e\x65olymp.runtime\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/runtime/language.proto\x1a\x1c\x65olymp/runtime/runtime.proto\x1a!eolymp/wellknown/expression.proto\",\n\x15\x44\x65scribeLanguageInput\x12\x13\n\x0blanguage_id\x18\x01 \x01(\t\"D\n\x16\x44\x65scribeLanguageOutput\x12*\n\x08language\x18\x01 \x01(\x0b\x32\x18.eolymp.runtime.Language\"\x9f\x02\n\x12ListLanguagesInput\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.runtime.ListLanguagesInput.Filter\x1a\xcc\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\">\n\x13ListLanguagesOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.runtime.Language\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"A\n\x15\x44\x65scribeRuntimeOutput\x12(\n\x07runtime\x18\x01 \x01(\x0b\x32\x17.eolymp.runtime.Runtime\"\xfc\x02\n\x11ListRuntimesInput\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.runtime.ListRuntimesInput.Filter\x1a\xab\x02\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12,\n\x04lang\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07version\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"<\n\x12ListRuntimesOutput\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime\"/\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t2\xe3\x06\n\x0eRuntimeService\x12\xaf\x01\n\x10\x44\x65scribeLanguage\x12%.eolymp.runtime.DescribeLanguageInput\x1a&.eolymp.runtime.DescribeLanguageOutput\"L\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\x1a\x12\x18/languages/{language_id}\x12\x98\x01\n\rListLanguages\x12\".eolymp.runtime.ListLanguagesInput\x1a#.eolymp.runtime.ListLanguagesOutput\">\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\x0c\x12\n/languages\x12\xa9\x01\n\x0f\x44\x65scribeRuntime\x12$.eolymp.runtime.DescribeRuntimeInput\x1a%.eolymp.runtime.DescribeRuntimeOutput\"I\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\x17\x12\x15/runtime/{runtime_id}\x12\x93\x01\n\x0cListRuntimes\x12!.eolymp.runtime.ListRuntimesInput\x1a\".eolymp.runtime.ListRuntimesOutput\"<\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02\n\x12\x08/runtime\x12\xc1\x01\n\x14\x44\x65scribeCodeTemplate\x12).eolymp.runtime.DescribeCodeTemplateInput\x1a*.eolymp.runtime.DescribeCodeTemplateOutput\"R\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x18\x8a\xe3\n\x14runtime:runtime:read\x82\xd3\xe4\x93\x02 \x12\x1e/runtime/{runtime_id}/templateB1Z/github.com/eolymp/go-sdk/eolymp/runtime;runtimeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.runtime.runtime_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/runtime;runtime'
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeLanguage']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeLanguage']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\032\022\030/languages/{language_id}'
  _globals['_RUNTIMESERVICE'].methods_by_name['ListLanguages']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['ListLanguages']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\014\022\n/languages'
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeRuntime']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeRuntime']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\027\022\025/runtime/{runtime_id}'
  _globals['_RUNTIMESERVICE'].methods_by_name['ListRuntimes']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['ListRuntimes']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002\n\022\010/runtime'
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeCodeTemplate']._loaded_options = None
  _globals['_RUNTIMESERVICE'].methods_by_name['DescribeCodeTemplate']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\030\212\343\n\024runtime:runtime:read\202\323\344\223\002 \022\036/runtime/{runtime_id}/template'
  _globals['_DESCRIBELANGUAGEINPUT']._serialized_start=251
  _globals['_DESCRIBELANGUAGEINPUT']._serialized_end=295
  _globals['_DESCRIBELANGUAGEOUTPUT']._serialized_start=297
  _globals['_DESCRIBELANGUAGEOUTPUT']._serialized_end=365
  _globals['_LISTLANGUAGESINPUT']._serialized_start=368
  _globals['_LISTLANGUAGESINPUT']._serialized_end=655
  _globals['_LISTLANGUAGESINPUT_FILTER']._serialized_start=451
  _globals['_LISTLANGUAGESINPUT_FILTER']._serialized_end=655
  _globals['_LISTLANGUAGESOUTPUT']._serialized_start=657
  _globals['_LISTLANGUAGESOUTPUT']._serialized_end=719
  _globals['_DESCRIBERUNTIMEINPUT']._serialized_start=721
  _globals['_DESCRIBERUNTIMEINPUT']._serialized_end=763
  _globals['_DESCRIBERUNTIMEOUTPUT']._serialized_start=765
  _globals['_DESCRIBERUNTIMEOUTPUT']._serialized_end=830
  _globals['_LISTRUNTIMESINPUT']._serialized_start=833
  _globals['_LISTRUNTIMESINPUT']._serialized_end=1213
  _globals['_LISTRUNTIMESINPUT_FILTER']._serialized_start=914
  _globals['_LISTRUNTIMESINPUT_FILTER']._serialized_end=1213
  _globals['_LISTRUNTIMESOUTPUT']._serialized_start=1215
  _globals['_LISTRUNTIMESOUTPUT']._serialized_end=1275
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_start=1277
  _globals['_DESCRIBECODETEMPLATEINPUT']._serialized_end=1324
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_start=1326
  _globals['_DESCRIBECODETEMPLATEOUTPUT']._serialized_end=1372
  _globals['_RUNTIMESERVICE']._serialized_start=1375
  _globals['_RUNTIMESERVICE']._serialized_end=2242
# @@protoc_insertion_point(module_scope)
